==> qtjambi-qml-debuginfo-macos-6.6.3.jar: sources/QtJambiQml/QJSNumberCoercion_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQml/qjsnumbercoercion.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QJSNumberCoercion(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QJSNumberCoercion")
    QJSNumberCoercion *_ptr = reinterpret_cast<QJSNumberCoercion *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QJSNumberCoercion(QJSNumberCoercion)
void __qt_construct_QJSNumberCoercion_cref_QJSNumberCoercion(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QJSNumberCoercion(QJSNumberCoercion)")
    jobject other0 = __java_arguments[0].l;
    const QJSNumberCoercion& __qt_other0 = qtjambi_cast<const QJSNumberCoercion& >(__jni_env, other0);
    QJSNumberCoercion *__qt_this = new(__qtjambi_ptr) QJSNumberCoercion(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QJSNumberCoercion::QJSNumberCoercion(QJSNumberCoercion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_initialize_1native__Lio_qt_qml_QJSNumberCoercion_2Lio_qt_qml_QJSNumberCoercion_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::QJSNumberCoercion(QJSNumberCoercion)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QJSNumberCoercion_cref_QJSNumberCoercion, sizeof(QJSNumberCoercion), typeid(QJSNumberCoercion), false, &deleter_QJSNumberCoercion, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QJSNumberCoercion::equals(double,double)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_equals__DD)
(JNIEnv *__jni_env,
 jclass,
 jdouble lhs0,
 jdouble rhs1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::equals(double,double)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QJSNumberCoercion::equals(static_cast<double>(lhs0), static_cast<double>(rhs1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSNumberCoercion::isArrayIndex(double)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_isArrayIndex__D)
(JNIEnv *__jni_env,
 jclass,
 jdouble d0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::isArrayIndex(double)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QJSNumberCoercion::isArrayIndex(static_cast<double>(d0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSNumberCoercion::isInteger(double)
extern "C" QT_DEPRECATED Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_isInteger__D)
(JNIEnv *__jni_env,
 jclass,
 jdouble d0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::isInteger(double)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QJSNumberCoercion::isInteger(static_cast<double>(d0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSNumberCoercion::toInteger(double)
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_toInteger__D)
(JNIEnv *__jni_env,
 jclass,
 jdouble d0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::toInteger(double)")
    jint __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QJSNumberCoercion::toInteger(static_cast<double>(d0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QJSNumberCoercion *__qt_this = QtJambiAPI::objectFromNativeId<QJSNumberCoercion>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QJSNumberCoercion(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QJSNumberCoercion(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QJSNumberCoercion>("QJSNumberCoercion", "io/qt/qml/QJSNumberCoercion");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QJSNumberCoercion);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.7.0.jar: sources/QtJambiQml/QJSNumberCoercion_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qjsnumbercoercion.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QJSNumberCoercion(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QJSNumberCoercion")
    QJSNumberCoercion *_ptr = reinterpret_cast<QJSNumberCoercion *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QJSNumberCoercion(QJSNumberCoercion)
void __qt_construct_QJSNumberCoercion_cref_QJSNumberCoercion(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QJSNumberCoercion(QJSNumberCoercion)")
    jobject other0 = __java_arguments[0].l;
    const QJSNumberCoercion& __qt_other0 = qtjambi_cast<const QJSNumberCoercion& >(__jni_env, other0);
    QJSNumberCoercion *__qt_this = new(__qtjambi_ptr) QJSNumberCoercion(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QJSNumberCoercion::QJSNumberCoercion(QJSNumberCoercion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_initialize_1native__Lio_qt_qml_QJSNumberCoercion_2Lio_qt_qml_QJSNumberCoercion_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::QJSNumberCoercion(QJSNumberCoercion)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QJSNumberCoercion_cref_QJSNumberCoercion, sizeof(QJSNumberCoercion), typeid(QJSNumberCoercion), false, &deleter_QJSNumberCoercion, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QJSNumberCoercion::equals(double,double)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_equals__DD)
(JNIEnv *__jni_env,
 jclass,
 jdouble lhs0,
 jdouble rhs1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::equals(double,double)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QJSNumberCoercion::equals(static_cast<double>(lhs0), static_cast<double>(rhs1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSNumberCoercion::isArrayIndex(double)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_isArrayIndex__D)
(JNIEnv *__jni_env,
 jclass,
 jdouble d0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::isArrayIndex(double)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QJSNumberCoercion::isArrayIndex(static_cast<double>(d0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSNumberCoercion::isInteger(double)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_isInteger__D)
(JNIEnv *__jni_env,
 jclass,
 jdouble d0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::isInteger(double)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QJSNumberCoercion::isInteger(static_cast<double>(d0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QJSNumberCoercion::toInteger(double)
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_toInteger__D)
(JNIEnv *__jni_env,
 jclass,
 jdouble d0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QJSNumberCoercion::toInteger(double)")
    jint __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QJSNumberCoercion::toInteger(static_cast<double>(d0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QJSNumberCoercion_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QJSNumberCoercion *__qt_this = QtJambiAPI::objectFromNativeId<QJSNumberCoercion>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QJSNumberCoercion(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QJSNumberCoercion(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QJSNumberCoercion>("QJSNumberCoercion", "io/qt/qml/QJSNumberCoercion");
// BEGIN: function table
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QJSNumberCoercion);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
